@@ -13,6 +13,7 @@
 from gi.repository import GLib, GdkPixbuf, Gio, Gst
 
 import re
+from random import choice
 
 from lollypop.tagreader import TagReader
 from lollypop.define import App, ArtSize, ArtHelperEffect
@@ -167,10 +168,9 @@ class AlbumArt:
         try:
             # Look in cache
             f = Gio.File.new_for_path(cache_path_jpg)
-            if f.query_exists():
-                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(cache_path_jpg,
-                                                                width,
-                                                                height)
+            if not effect & ArtHelperEffect.NO_CACHE and f.query_exists():
+                pixbuf = GdkPixbuf.Pixbuf.new_from_file(cache_path_jpg)
+                return pixbuf
             else:
                 # Use favorite folder artwork
                 if pixbuf is None:
@@ -181,21 +181,18 @@ class AlbumArt:
                         (status, data, tag) = f.load_contents(None)
                         bytes = GLib.Bytes(data)
                         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
-                        pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
-                            stream,
-                            width,
-                            height,
-                            True,
-                            None)
-                        # Pixbuf will be resized, cropping not needed
-                        if not effect & ArtHelperEffect.RESIZE:
-                            pixbuf = self._crop_pixbuf(pixbuf)
+                        pixbuf = GdkPixbuf.Pixbuf.new_from_stream(
+                            stream, None)
                         stream.close()
                 # Use tags artwork
-                if pixbuf is None and album.tracks:
+                if pixbuf is None and album.tracks and album.uri != "":
                     try:
-                        pixbuf = self.pixbuf_from_tags(
-                            album.tracks[0].uri, width, height)
+                        if effect & ArtHelperEffect.RESIZE:
+                            track = album.tracks[0]
+                        else:
+                            track = choice(album.tracks)
+                        pixbuf = self.pixbuf_from_tags(track.uri,
+                                                       width, height)
                     except Exception as e:
                         print("AlbumArt::get_album_artwork()", e)
 
@@ -208,16 +205,14 @@ class AlbumArt:
                         (status, data, tag) = f.load_contents(None)
                         bytes = GLib.Bytes(data)
                         stream = Gio.MemoryInputStream.new_from_bytes(bytes)
-                        pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
-                            stream,
-                            width,
-                            height,
-                            True,
-                            None)
+                        pixbuf = GdkPixbuf.Pixbuf.new_from_stream(
+                            stream, None)
                         stream.close()
-                        # Pixbuf will be resized, cropping not needed
-                        if not effect & ArtHelperEffect.RESIZE:
-                            pixbuf = self._crop_pixbuf(pixbuf)
+                # Pixbuf will be resized, cropping not needed
+                if pixbuf is not None and not effect & ArtHelperEffect.RESIZE:
+                    pixbuf = self._crop_pixbuf(pixbuf)
+                    pixbuf = pixbuf.scale_simple(width, height,
+                                                 GdkPixbuf.InterpType.BILINEAR)
                 # Search on the web
                 if pixbuf is None:
                     self.cache_album_art(album.id)
@@ -370,11 +365,7 @@ class AlbumArt:
             if exist:
                 bytes = GLib.Bytes(mapflags.data)
                 stream = Gio.MemoryInputStream.new_from_bytes(bytes)
-                pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
-                                                                   width,
-                                                                   height,
-                                                                   False,
-                                                                   None)
+                pixbuf = GdkPixbuf.Pixbuf.new_from_stream(stream, None)
                 stream.close()
         except Exception as e:
             Logger.error("AlbumArt::pixbuf_from_tags(): %s" % e)
