@@ -101,7 +101,7 @@ class ArtistsDatabase:
         """
             Get artist name
             @param Artist id as int
-            @return Artist name as string
+            @return str
         """
         with SqlCursor(App().db) as sql:
             if artist_id == Type.COMPILATIONS:
@@ -112,7 +112,7 @@ class ArtistsDatabase:
             v = result.fetchone()
             if v is not None:
                 return v[0]
-            return None
+            return ""
 
     def set_mb_artist_id(self, artist_id, mb_artist_id):
         """
@@ -226,10 +226,10 @@ class ArtistsDatabase:
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
-                    "SELECT DISTINCT %s FROM artists, album_artists, albums\
-                                  WHERE artists.rowid=album_artists.artist_id\
-                                  AND albums.rowid=album_artists.album_id\
-                                  AND albums.mtime!=0\
+                    "SELECT DISTINCT %s FROM artists, track_artists, tracks\
+                                  WHERE artists.rowid=track_artists.artist_id\
+                                  AND tracks.rowid=track_artists.track_id\
+                                  AND tracks.mtime!=0\
                                   ORDER BY artists.sortname\
                                   COLLATE NOCASE COLLATE LOCALIZED" % select)
             else:
@@ -307,9 +307,7 @@ class ArtistsDatabase:
                            ("%" + no_accents + "%",)]:
                 request = "SELECT artists.rowid\
                            FROM artists, albums, album_artists\
-                           WHERE album_artists.artist_id=artists.rowid\
-                           AND album_artists.album_id=albums.rowid\
-                           AND noaccents(artists.name) LIKE ? LIMIT 25"
+                           WHERE noaccents(artists.name) LIKE ? LIMIT 25"
                 result = sql.execute(request, filter)
                 items += list(itertools.chain(*result))
             return items
