@@ -10,7 +10,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gettext import gettext as _
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
@@ -67,19 +66,7 @@ class GenresDatabase:
             v = result.fetchone()
             if v is not None:
                 return v[0]
-            return _("Unknown")
-
-    def get_names(self):
-        """
-            Get genre name for genre id
-            @return genres as [str]
-        """
-        with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT name\
-                                 FROM genres\
-                                 ORDER BY name\
-                                 COLLATE NOCASE COLLATE LOCALIZED")
-            return list(itertools.chain(*result))
+            return None
 
     def get_album_ids(self, genre_id, ignore=False):
         """
@@ -128,6 +115,11 @@ class GenresDatabase:
             result = sql.execute("SELECT DISTINCT\
                                   genres.rowid, genres.name,genres.name\
                                   FROM genres\
+                                  WHERE genres.rowid IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres, albums\
+                                    WHERE album_genres.album_id=albums.rowid\
+                                    AND albums.mtime!=0)\
                                   ORDER BY genres.name\
                                   COLLATE NOCASE COLLATE LOCALIZED")
             return list(result)
@@ -140,25 +132,21 @@ class GenresDatabase:
         with SqlCursor(App().db) as sql:
             result = sql.execute("SELECT DISTINCT genres.rowid\
                                   FROM genres\
+                                  WHERE genres.rowid IN (\
+                                    SELECT album_genres.genre_id\
+                                    FROM album_genres, albums\
+                                    WHERE album_genres.album_id=albums.rowid\
+                                    AND albums.mtime!=0)\
                                   ORDER BY genres.name\
                                   COLLATE NOCASE COLLATE LOCALIZED")
             return list(itertools.chain(*result))
 
-    def clean(self, genre_id):
+    def clean(self):
         """
-            Clean database for genre id
-            @param genre id as int
-            @return cleaned as bool
-            @warning commit needed
+            Clean genres
         """
         with SqlCursor(App().db, True) as sql:
-            cleaned = False
-            result = sql.execute("SELECT track_id from track_genres\
-                                 WHERE genre_id=?\
-                                 LIMIT 1", (genre_id,))
-            v = result.fetchone()
-            if not v:
-                cleaned = True
-                sql.execute("DELETE FROM genres\
-                            WHERE rowid=?", (genre_id,))
-            return cleaned
+            sql.execute("DELETE FROM genres WHERE genres.rowid NOT IN (\
+                            SELECT album_genres.genre_id FROM album_genres)")
+            sql.execute("DELETE FROM genres WHERE genres.rowid NOT IN (\
+                            SELECT track_genres.genre_id FROM track_genres)")
