@@ -12,7 +12,7 @@
 
 from gi.repository import GObject
 
-from lollypop.define import App, NextContext
+from lollypop.define import App
 from lollypop.objects import Track
 
 
@@ -22,18 +22,18 @@ class BasePlayer(GObject.GObject):
     """
     __gsignals__ = {
         "current-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
+        "duration-changed": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+        "loading-changed": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
         "album-added": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "album-removed": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "playlist-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "next-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "prev-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "seeked": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
-        "lock-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "status-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "volume-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "queue-changed": (GObject.SignalFlags.RUN_FIRST, None, ()),
-        "rate-changed": (GObject.SignalFlags.RUN_FIRST, None,
-                         (GObject.TYPE_PYOBJECT,)),
+        "rate-changed": (GObject.SignalFlags.RUN_FIRST, None, (int, int)),
         "party-changed": (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
@@ -46,19 +46,15 @@ class BasePlayer(GObject.GObject):
         if not hasattr(self, "_albums"):
             GObject.GObject.__init__(self)
             self._base_init = True
-            # Lock adding tracks to playback, do nothing here, just get it
-            # with locked property
-            self._is_locked = False
             # Should player do crossfading
             self._crossfading = False
-            # Keep track of artist/album finished
-            self._next_context = NextContext.NONE
             # A user playlist used as current playlist
             self._playlist_ids = []
             self._playlist_tracks = []
             # Used by shuffle tracks to restore user playlist before shuffle
             self._playlist_backup = None
             self._current_track = Track()
+            self._current_playback_track = Track()
             self._next_track = Track()
             self._prev_track = Track()
             # Albums in current playlist
@@ -68,28 +64,6 @@ class BasePlayer(GObject.GObject):
             # For tracks from the cmd line
             self._external_tracks = []
 
-    def lock(self):
-        """
-            Mark player as locked
-        """
-        self._is_locked = not self._is_locked
-        self.emit("lock-changed")
-
-    @property
-    def is_locked(self):
-        """
-            Is player.is_locked as bool
-        """
-        return self._is_locked
-
-    def reset_pcn(self):
-        """
-            Reset prev, current, next
-        """
-        self._current_track = Track()
-        self._prev_track = Track()
-        self._next_track = Track()
-
     def set_next(self):
         """
             Set next track
