@@ -24,8 +24,15 @@ class PluginsPlayer:
 
     def __init__(self, playbin):
         """
-            Init replay gain on playbin
-            @param playbin as Gst play bin
+            Init playbin
+            @param playbin as Gst.bin
+        """
+        self.__playbin = playbin
+        self.init()
+
+    def init(self):
+        """
+            Init playbin
         """
         bin = Gst.ElementFactory.make("bin", "bin")
 
@@ -35,8 +42,6 @@ class PluginsPlayer:
                                                    "audioconvert2")
         rg_audioconvert3 = Gst.ElementFactory.make("audioconvert",
                                                    "audioconvert3")
-        rg_audioconvert4 = Gst.ElementFactory.make("audioconvert",
-                                                   "audioconvert4")
         self.volume = Gst.ElementFactory.make("volume",
                                               "volume")
         self.volume.props.volume = 0.0
@@ -46,8 +51,7 @@ class PluginsPlayer:
                                             "rglimiter")
         rg_audiosink = Gst.ElementFactory.make("autoaudiosink",
                                                "autoaudiosink")
-        self.__equalizer = Gst.ElementFactory.make("equalizer-10bands",
-                                                   "equalizer-10bands")
+
         if not bin or not rg_audioconvert1 or\
            not rg_audioconvert2 or not self.rgvolume or\
            not rglimiter or not rg_audiosink:
@@ -65,23 +69,37 @@ class PluginsPlayer:
         bin.add(rg_audioconvert1)
         bin.add(rg_audioconvert2)
         bin.add(rg_audioconvert3)
-        bin.add(rg_audioconvert4)
         bin.add(rglimiter)
-        bin.add(self.__equalizer)
         bin.add(rg_audiosink)
+
+        if App().settings.get_value("equalizer-enabled"):
+            self.__equalizer = Gst.ElementFactory.make("equalizer-10bands",
+                                                       "equalizer-10bands")
+            rg_audioconvert4 = Gst.ElementFactory.make("audioconvert",
+                                                       "audioconvert4")
+            bin.add(rg_audioconvert4)
+            bin.add(self.__equalizer)
+        else:
+            self.__equalizer = None
+
         rg_audioconvert1.link(self.rgvolume)
         self.rgvolume.link(rg_audioconvert2)
         self.rgvolume.link(rglimiter)
         rg_audioconvert2.link(self.volume)
         self.volume.link(rg_audioconvert3)
-        rg_audioconvert3.link(self.__equalizer)
-        self.__equalizer.link(rg_audioconvert4)
-        rg_audioconvert4.link(rg_audiosink)
+
+        if self.__equalizer is None:
+            rg_audioconvert3.link(rg_audiosink)
+        else:
+            rg_audioconvert3.link(self.__equalizer)
+            self.__equalizer.link(rg_audioconvert4)
+            rg_audioconvert4.link(rg_audiosink)
 
         bin.add_pad(Gst.GhostPad.new(
             "sink",
             rg_audioconvert1.get_static_pad("sink")))
-        playbin.set_property("audio-sink", bin)
+        self.__playbin.set_property("audio-sink", bin)
+        self.update_equalizer()
 
     def update_equalizer(self):
         """
@@ -99,7 +117,8 @@ class PluginsPlayer:
             @param value as int
         """
         try:
-            self.__equalizer.set_property("band%s" % band, value)
+            if self.__equalizer is not None:
+                self.__equalizer.set_property("band%s" % band, value)
         except Exception as e:
             Logger.error("PluginsPlayer::set_equalizer():", e)
 
