@@ -341,11 +341,27 @@ def is_readonly(uri):
     """
         Check if uri is readonly
     """
-    f = Gio.File.new_for_uri(uri)
-    info = f.query_info("access::can-write",
-                        Gio.FileQueryInfoFlags.NONE,
-                        None)
-    return not info.get_attribute_boolean("access::can-write")
+    try:
+        f = Gio.File.new_for_uri(uri)
+        info = f.query_info("access::can-write",
+                            Gio.FileQueryInfoFlags.NONE,
+                            None)
+        return not info.get_attribute_boolean("access::can-write")
+    except:
+        return True
+
+
+def create_dir(path):
+    """
+        Create dir
+        @param path as str
+    """
+    d = Gio.File.new_for_path(path)
+    if not d.query_exists():
+        try:
+            d.make_directory_with_parents()
+        except:
+            Logger.info("Can't create %s" % path)
 
 
 def remove_static(ids):
