@@ -74,4 +74,4 @@ class AlbumsDecadeBoxView(FlowBoxView):
         if show_sidebar and show_genres and not App().window.is_adaptive:
             App().window.container.list_two.select_ids(widget.data)
         else:
-            App().window.container.show_view(Type.YEARS, widget.data)
+            App().window.container.show_view([Type.YEARS], widget.data)
