@@ -35,7 +35,7 @@ class ArtistAlbumsView(LazyLoadingView, ViewController):
         self._artist_ids = artist_ids
         self._genre_ids = genre_ids
         self._album_box = Gtk.Grid()
-        self._album_box.set_row_spacing(20)
+        self._album_box.set_row_spacing(50)
         self._album_box.set_orientation(Gtk.Orientation.VERTICAL)
         self._album_box.set_property("valign", Gtk.Align.START)
         self._album_box.show()
@@ -84,15 +84,14 @@ class ArtistAlbumsView(LazyLoadingView, ViewController):
             child.set_selection()
             child.set_playing_indicator()
 
-    def _on_artwork_changed(self, artwork, album_id):
+    def _on_duration_changed(self, player, track_id):
         """
-            Update children artwork if matching album id
-            @param artwork as Artwork
-            @param album_id as int
+            Update track duration
+            @param player as Player
+            @param track_id as int
         """
         for child in self.children:
-            if child.album.id == album_id:
-                child.set_artwork()
+            child.update_duration(track_id)
 
     def _on_search_changed(self, entry):
         """
